// Mod: Date Range for Xin Calendar 2 (In-Page/Popup-Window)
// Copyright 2004  Xin Yang    All Rights Reserved.

// Last Modified: 04-Aug-2006

// User interface
function setRange(confName,startDate,endDate) {
  if (xcGoodDateRange(startDate,endDate)) {
    xcRegisterConf(confName,"dateRange","range",[xcTransformDate(startDate,xcDateFormat,xcInternalDateFormat),xcTransformDate(endDate,xcDateFormat,xcInternalDateFormat)],0);
  }
}

function setWeekDays(confName,sun,mon,tue,wed,thu,fri,sat) {
  xcRegisterConf(confName,"dateRange","ranges",{"type":"daySwitch","conf":[sun,mon,tue,wed,thu,fri,sat]},1);
}

function setDays(confName,sun,wk,sat) {
  setWeekDays(confName,sun,wk,wk,wk,wk,wk,sat);
}

function enableRange(confName,startDate,endDate) {
  if (xcGoodDateRange(startDate,endDate)) {
    xcRegisterConf(confName,"dateRange","ranges",{"type":"rangeOn","conf":[xcTransformDate(startDate,xcDateFormat,xcInternalDateFormat),xcTransformDate(endDate,xcDateFormat,xcInternalDateFormat)]},1);
  }
}

function disableRange(confName,startDate,endDate) {
  if (xcGoodDateRange(startDate,endDate)) {
    xcRegisterConf(confName,"dateRange","ranges",{"type":"rangeOff","conf":[xcTransformDate(startDate,xcDateFormat,xcInternalDateFormat),xcTransformDate(endDate,xcDateFormat,xcInternalDateFormat)]},1);
  }
}

function enableDates(confName,dates) {
  var dateList=xcTakeDates(dates);
  for (var i=0; i<dateList.length; i++) {
    xcRegisterConf(confName,"dateRange",xcTransformDate(dateList[i],xcDateFormat,xcInternalDateFormat),false,0);
  }
}

function disableDates(confName,dates) {
  var dateList=xcTakeDates(dates);
  for (var i=0; i<dateList.length; i++) {
    xcRegisterConf(confName,"dateRange",xcTransformDate(dateList[i],xcDateFormat,xcInternalDateFormat),true,0);
  }
}

function daysBefore(n) { return xcDaysOffset(new Date(),-n); }
function daysAfter(n) { return xcDaysOffset(new Date(),n); }
function dayOffset(dateBase,n) { return xcDaysOffset(toJSDate(dateBase||""),n); }
function getWeekBegin(dateBase,n) {
  var d=toJSDate(dateBase||"");
  d.setTime(d.getTime()+xcOneDay(7*(n||0)-d.getDay()+xcWeekStart));
  return toCalendarDate(d);
}
function getWeekEnd(dateBase,n) {
  var d=toJSDate(dateBase||"");
  d.setTime(d.getTime()+xcOneDay(7*(n||0)-d.getDay()+6+xcWeekStart));
  return toCalendarDate(d);
}
function getMonthBegin(dateBase,n) {
  var d=toJSDate(dateBase||""), targetDate=new Date(d.getFullYear(),d.getMonth()+(n||0),1);
  return toCalendarDate(targetDate);
}
function getMonthEnd(dateBase,n) {
  var d=toJSDate(dateBase||""), nextMonth=new Date(d.getFullYear(),d.getMonth()+(n||0)+1,1);
  nextMonth.setTime(nextMonth.getTime()-xcOneDay(1));
  return toCalendarDate(nextMonth);
}
function getYearBegin(n) { return xcGetDateFromYMD((new Date()).getFullYear()+(n||0),0,1); }
function getYearEnd(n) { return xcGetDateFromYMD((new Date()).getFullYear()+(n||0),11,31); }

// Internal functions
function xcGoodDateRange(startDate,endDate) {
  var calRE=xcGetDateFormatRE();
  return ((startDate=="" || calRE.test(startDate)) && (endDate=="" || calRE.test(endDate)));
}

function xcDaysOffset(d,n) {
  d.setTime(d.getTime()+xcOneDay(n));
  return toCalendarDate(d);
}

function xcTakeDates(dates) {
  return dates.match(new RegExp(_xcGetDateFormatRE(), "g"));
}

function xcOneDay(n) { return 86400000*n; }

// Overloaded functions
function xcCheckDateRange(dir) {
  var range=this.getConf("dateRange","range");

  if (range!=null) {
    var firstDay=xcGetInternalDate(this.year,this.month,1);

    if (dir<=0 && range[0]!="") {
      var thisMonth=new Date(this.year,this.month+1,0);
      var lastDay=xcGetInternalDate(thisMonth.getFullYear(),thisMonth.getMonth(),thisMonth.getDate());
      if (lastDay<range[0]) {
        this.year=range[0].substring(0,4)-0;
        this.month=range[0].substring(4,6)-1;
      }
    }

    if (dir>=0 && range[1]!="") {
      if (firstDay>range[1]) {
        this.year=range[1].substring(0,4)-0;
        this.month=range[1].substring(4,6)-1;
      }
    }
  }
}

function xcDateOff() {
  var calDate=xcGetInternalDate(this.cellYear,this.cellMonth,this.cellDate);

  var range=this.getConf("dateRange","range");
  if (range) {
    if (range[0]!="" && range[0]>calDate || range[1]!="" && calDate>range[1]) {
      return true;
    }
  }

  var dateSwitch=this.getConf("dateRange",calDate);
  if (dateSwitch!=null) {
    return dateSwitch;
  }

  var dateOff=false, ranges=this.getConf("dateRange","ranges");
  if (ranges) {
    for (var i=0; i<ranges.length; i++) {
      if (ranges[i]["type"]=="daySwitch") {
        dateOff=ranges[i]["conf"][this.cellDay-xcWeekStart]==0?true:false;
      }
      else if (ranges[i]["type"]=="rangeOn") {
        if (ranges[i]["conf"][0]<=calDate && calDate<=ranges[i]["conf"][1]) {
          dateOff=false;
        }
      }
      else if (ranges[i]["type"]=="rangeOff") {
        if (ranges[i]["conf"][0]<=calDate && calDate<=ranges[i]["conf"][1]) {
          dateOff=true;
        }
      }
    }
  }

  return dateOff;
}
